# 📱 Commands Reference

**Complete guide to all Hyperliquid Trading Bot commands**

## 🚀 Quick Start Commands

The most important commands to get started:

```
/start       # Show main menu with quick action buttons
/balance     # Check your account balance
/long BTC 10 # Open long position with $10 USDC
/long BTC 10 sl:9500 # Long with automatic stop loss
/sl BTC 9000 # Set stop loss at $9,000
/tp BTC 11000 # Set take profit at $11,000
/monitoring  # Check order monitoring status
/performance # Token performance ranking
/daily       # Daily performance (last 10 days)
/alarm BTC 50000 # Set price alert for BTC at $50,000
/risk        # Advanced risk metrics
/version     # Bot version and system info
/help        # Full command reference
```

**💡 Auto-Notifications:** The bot automatically monitors your orders every 10 seconds and sends notifications when orders are filled!

## 💼 Account Management

### `/balance`
Show your current account balance and P&L summary with detailed breakdown of available vs used funds.

**Example:**
```
/balance
```

**Response:**
```
💰 Account Balance

💵 USDC:
   📊 Total: 1,250.00
   ✅ Available: 1,150.00
   🔒 In Use: 100.00

💵 BTC:
   📊 Total: 0.002
   ✅ Available: 0.001
   🔒 In Use: 0.001

💼 Portfolio Summary:
   💰 Total Value: $1,250.00
   🚀 Available for Trading: $1,150.00
   🔒 In Active Use: $100.00

📊 Performance:
   💵 P&L: $150.00 (+13.64%)
   📈 Initial: $1,100.00
```

### `/positions`
Display all open positions with unrealized P&L and percentages.

**Example:**
```
/positions
```

**Response:**
```
📈 Open Positions

📊 BTC (LONG)
   📏 Size: 0.001000 BTC
   💰 Entry: $45,230.50
   💵 Value: $45.23
   🟢 P&L: $1.84 (+4.07%)

📊 ETH (SHORT)
   📏 Size: 0.010000 ETH
   💰 Entry: $3,200.00
   💵 Value: $32.00
   🔴 P&L: -$0.75 (-2.34%)

💼 Total Portfolio:
   💵 Total Value: $77.23
   🟢 Total P&L: $1.09 (+1.43%)
```

### `/orders [token (optional)]`
Show all pending/open orders, optionally filtered by token.

**Usage:**
```
/orders           # Show all open orders
/orders <TOKEN>   # Show open orders for specific token
```

**Examples:**
```
/orders       # Show all open orders
/orders BTC   # Show only Bitcoin orders
/orders ETH   # Show only Ethereum orders
```

**Response (All Orders):**
```
📋 All Open Orders

🟢 BTC
   📊 BUY 0.001 @ $44,500.00
   💵 Value: $44.50
   🔑 ID: abc123

🔴 ETH
   📊 SELL 0.01 @ $3,400.00
   💵 Value: $34.00
   🔑 ID: def456

💡 Filter by token: /orders BTC, /orders ETH
```

**Response (Filtered):**
```
📋 Open Orders - BTC

🟢 BTC
   📊 BUY 0.001 @ $44,500.00
   💵 Value: $44.50
   🔑 ID: abc123

🟢 BTC
   📊 BUY 0.002 @ $44,000.00
   💵 Value: $88.00
   🔑 ID: ghi789

💡 Quick Actions:
• /coo BTC - Cancel all BTC orders
• /orders - View all orders
```

**Response (No Orders):**
```
📭 No open orders for BTC

💡 No pending BTC orders found.
Use /long BTC 100 or /short BTC 100 to create new orders.
```

### `/coo [token]`
Cancel all open orders for a specific token.

**Usage:**
```
/coo <TOKEN>
```

**Examples:**
```
/coo BTC   # Cancel all Bitcoin orders
/coo ETH   # Cancel all Ethereum orders
```

**How it works:**
1. Fetches all open orders for the specified token
2. Shows confirmation dialog with order details
3. Cancels all orders after user confirmation
4. Reports success/failure for each order

**Confirmation Dialog:**
```
⚠️ Cancel All BTC Orders

📋 Orders to Cancel:
🟢 BUY 0.001 @ $44,500.00 ($44.50)
🟢 BUY 0.002 @ $44,000.00 ($88.00)
🔴 SELL 0.001 @ $46,000.00 ($46.00)

💰 Total Value: $178.50
🔢 Orders Count: 3

⚠️ Are you sure you want to cancel ALL BTC orders?

This action cannot be undone.
```

**Success Response:**
```
✅ Cancel Orders Results

📊 Summary:
• Token: BTC
• Cancelled: 3 orders
• Failed: 0 orders
• Total Attempted: 3 orders

🗑️ Successfully Cancelled:
🟢 BUY 0.001 @ $44,500.00
🟢 BUY 0.002 @ $44,000.00
🔴 SELL 0.001 @ $46,000.00

🎉 All BTC orders successfully cancelled!
```

### `/stats`
Complete trading statistics and performance metrics.

**Example:**
```
/stats
```

**Response:**
```
📊 Trading Statistics

💰 Balance Overview
• Initial: $1,000.00
• Current: $1,150.00
• Total P&L: $150.00
• Total Return: 15.00%

📈 Trading Activity
• Total Trades: 25
• Buy Orders: 13
• Sell Orders: 12
• Days Active: 30

🏆 Performance Metrics
• Win Rate: 68.0%
• Profit Factor: 2.15
• Avg Win: $45.50
• Avg Loss: $28.75
• Expectancy: $6.25

📊 Risk Metrics
• Sharpe Ratio: 1.85
• Sortino Ratio: 2.41
• Max Drawdown: 8.5%
• Volatility: 12.3%
• VaR (95%): 3.2%

🎯 Best/Worst
• Largest Win: $125.50
• Largest Loss: $45.25
• Max Consecutive Wins: 5
• Max Consecutive Losses: 2

📅 Since: 2024-01-15
```

## 📈 Performance Analytics

### `/performance [token (optional)]`
Show token performance ranking or detailed stats for a specific token.

**Usage:**
```
/performance         # Show all token rankings
/performance <TOKEN> # Detailed stats for specific token
```

**Examples:**
```
/performance       # Token performance ranking
/performance BTC   # Detailed Bitcoin performance
/performance ETH   # Detailed Ethereum performance
```

**Response (Ranking):**
```
🏆 Token Performance Ranking

🥇 BTC
   🟢 P&L: $245.50 (+12.3%)
   📊 Trades: 15 | Win: 73%

🥈 ETH
   🟢 P&L: $125.75 (+8.9%)
   📊 Trades: 12 | Win: 67%

🥉 SOL
   🔴 P&L: -$25.00 (-2.1%)
   📊 Trades: 8 | Win: 38%

💼 Portfolio Summary:
   🟢 Total P&L: $346.25
   📈 Tokens Traded: 3
   🔄 Completed Trades: 35

💡 Usage: /performance BTC for detailed BTC stats
```

**Response (Detailed):**
```
📊 BTC Detailed Performance

💰 P&L Summary:
• 🟢 Total P&L: $245.50 (+12.3%)
• 💵 Total Volume: $2,150.00
• 📈 Expectancy: $16.37

📊 Trading Activity:
• Total Trades: 20
• Completed: 15
• Buy Orders: 11
• Sell Orders: 9

🏆 Performance Metrics:
• Win Rate: 73.3%
• Profit Factor: 2.85
• Wins: 11 | Losses: 4

💡 Best/Worst:
• Largest Win: $85.50
• Largest Loss: $35.25
• Avg Win: $32.50
• Avg Loss: $18.75

🔄 Recent Trades:
• 🔴 SELL $450 @ 12/15 14:30 | P&L: $25.50
• 🟢 BUY $425 @ 12/14 09:15
• 🔴 SELL $380 @ 12/13 16:45 | P&L: $15.25

🔄 Use /performance to see all token rankings
```

### `/daily`
Show daily performance breakdown for the last 10 days.

**Example:**
```
/daily
```

**Response:**
```
📅 Daily Performance (Last 10 Days)

📊 Dec 15, 2024
   🟢 P&L: $45.25 (+2.1%)
   🔄 Trades: 3

📊 Dec 14, 2024
   🔴 P&L: -$15.50 (-0.7%)
   🔄 Trades: 2

📊 Dec 13, 2024
   🟢 P&L: $85.75 (+4.2%)
   🔄 Trades: 5

📊 Dec 12, 2024
   🟢 P&L: $12.00 (+0.6%)
   🔄 Trades: 1

📊 Dec 11, 2024
   🟢 P&L: $25.50 (+1.3%)
   🔄 Trades: 2

💼 10-Day Summary:
   🟢 Total P&L: $153.00
   🔄 Total Trades: 13
   📊 Avg per Day: $15.30
```

### `/weekly`
Show weekly performance breakdown for the last 10 weeks.

**Example:**
```
/weekly
```

**Response:**
```
📊 Weekly Performance (Last 10 Weeks)

📈 Week Dec 9-15, 2024
   🟢 P&L: $125.50 (+5.8%)
   🔄 Trades: 8

📈 Week Dec 2-8, 2024
   🟢 P&L: $85.25 (+4.1%)
   🔄 Trades: 6

📈 Week Nov 25-Dec 1, 2024
   🔴 P&L: -$25.75 (-1.2%)
   🔄 Trades: 4

📈 Week Nov 18-24, 2024
   🟢 P&L: $45.00 (+2.3%)
   🔄 Trades: 3

💼 10-Week Summary:
   🟢 Total P&L: $230.00
   🔄 Total Trades: 21
   📊 Avg per Week: $23.00
```

### `/monthly`
Show monthly performance breakdown for the last 10 months.

**Example:**
```
/monthly
```

**Response:**
```
📆 Monthly Performance (Last 10 Months)

📅 December 2024
   🟢 P&L: $245.50 (+11.2%)
   🔄 Trades: 15

📅 November 2024
   🟢 P&L: $185.25 (+9.1%)
   🔄 Trades: 12

📅 October 2024
   🔴 P&L: -$45.75 (-2.1%)
   🔄 Trades: 8

📅 September 2024
   🟢 P&L: $125.00 (+6.5%)
   🔄 Trades: 10

💼 10-Month Summary:
   🟢 Total P&L: $510.00
   🔄 Total Trades: 45
   📊 Avg per Month: $51.00
```

## 🚀 Perps Trading

### `/long [token] [USDC amount] [price (optional)] [sl:price (optional)]`
Open a long position using market order or limit order, with optional automatic stop loss.

**Usage:**
```
/long <TOKEN> <USDC_AMOUNT>                    # Market order
/long <TOKEN> <USDC_AMOUNT> <PRICE>            # Limit order
/long <TOKEN> <USDC_AMOUNT> sl:<STOP_PRICE>    # Market order with stop loss
/long <TOKEN> <USDC_AMOUNT> <PRICE> sl:<STOP_PRICE> # Limit order with stop loss
```

**Examples:**
```
/long BTC 100              # Long Bitcoin with $100 USDC (Market Order)
/long BTC 100 45000        # Long Bitcoin with $100 USDC at $45,000 (Limit Order)
/long BTC 100 sl:44000     # Market order with automatic stop loss at $44,000
/long BTC 100 45000 sl:44000 # Limit order at $45,000 with stop loss at $44,000
/long ETH 50               # Long Ethereum with $50 USDC (Market Order)
/long ETH 50 3200          # Long Ethereum with $50 USDC at $3,200 (Limit Order)
/long ETH 50 sl:3100       # Market order with stop loss at $3,100
/long ETH 50 3200 sl:3100  # Limit order with stop loss at $3,100
```

**Stop Loss Validation:**
- For LONG positions: Stop loss price must be BELOW entry price
- Stop loss is placed automatically when the original order fills
- Uses `sl:price` format to distinguish from limit price

**How it works:**
1. **Market Order** (2 parameters): Fetches current market price and places market buy order
2. **Limit Order** (3 parameters): Places limit buy order at specified price
3. **With Stop Loss**: Saves stop loss for automatic placement when order fills
4. Calculates token amount: `token_amount = usdc_amount / price`
5. Records trade in statistics

**Market Order Confirmation:**
```
🟢 Long Position Confirmation

📊 Order Details:
• Token: BTC
• Direction: LONG (Buy)
• USDC Value: $100.00
• Current Price: $45,230.50
• Order Type: Market Order
• Token Amount: 0.002211 BTC

🎯 Execution:
• Will buy 0.002211 BTC at current market price
• Est. Value: $100.00

⚠️ Are you sure you want to open this long position?
```

**Limit Order Confirmation:**
```
🟢 Long Position Confirmation

📊 Order Details:
• Token: BTC
• Direction: LONG (Buy)
• USDC Value: $100.00
• Current Price: $45,230.50
• Order Type: Limit Order
• Token Amount: 0.002222 BTC

🎯 Execution:
• Will buy 0.002222 BTC at $45,000.00
• Est. Value: $100.00

⚠️ Are you sure you want to open this long position?
```

### `/short [token] [USDC amount] [price (optional)] [sl:price (optional)]`
Open a short position using market order or limit order, with optional automatic stop loss.

**Usage:**
```
/short <TOKEN> <USDC_AMOUNT>                    # Market order
/short <TOKEN> <USDC_AMOUNT> <PRICE>            # Limit order
/short <TOKEN> <USDC_AMOUNT> sl:<STOP_PRICE>    # Market order with stop loss
/short <TOKEN> <USDC_AMOUNT> <PRICE> sl:<STOP_PRICE> # Limit order with stop loss
```

**Examples:**
```
/short BTC 100              # Short Bitcoin with $100 USDC (Market Order)
/short BTC 100 46000        # Short Bitcoin with $100 USDC at $46,000 (Limit Order)
/short BTC 100 sl:47000     # Market order with automatic stop loss at $47,000
/short BTC 100 46000 sl:47000 # Limit order at $46,000 with stop loss at $47,000
/short ETH 50               # Short Ethereum with $50 USDC (Market Order)
/short ETH 50 3400          # Short Ethereum with $50 USDC at $3,400 (Limit Order)
/short ETH 50 sl:3500       # Market order with stop loss at $3,500
/short ETH 50 3400 sl:3500  # Limit order with stop loss at $3,500
```

**Stop Loss Validation:**
- For SHORT positions: Stop loss price must be ABOVE entry price
- Stop loss is placed automatically when the original order fills
- Uses `sl:price` format to distinguish from limit price

**How it works:**
1. **Market Order** (2 parameters): Fetches current market price and places market sell order
2. **Limit Order** (3 parameters): Places limit sell order at specified price
3. **With Stop Loss**: Saves stop loss for automatic placement when order fills
4. Calculates token amount: `token_amount = usdc_amount / price`
5. Records trade in statistics

**Market Order Confirmation:**
```
🔴 Short Position Confirmation

📊 Order Details:
• Token: BTC
• Direction: SHORT (Sell)
• USDC Value: $100.00
• Current Price: $45,230.50
• Order Type: Market Order
• Token Amount: 0.002211 BTC

🎯 Execution:
• Will sell 0.002211 BTC at current market price
• Est. Value: $100.00

⚠️ Are you sure you want to open this short position?
```

**Limit Order Confirmation:**
```
🔴 Short Position Confirmation

📊 Order Details:
• Token: BTC
• Direction: SHORT (Sell)
• USDC Value: $100.00
• Current Price: $45,230.50
• Order Type: Limit Order
• Token Amount: 0.002174 BTC

🎯 Execution:
• Will sell 0.002174 BTC at $46,000.00
• Est. Value: $100.00

⚠️ Are you sure you want to open this short position?
```

### `/exit [token]`
Close an open position using market order.

**Usage:**
```
/exit <TOKEN>
```

**Examples:**
```
/exit BTC     # Close Bitcoin position (long or short)
/exit ETH     # Close Ethereum position
/exit SOL     # Close Solana position
```

**How it works:**
1. Checks for existing position in the specified token
2. Determines position direction (long/short) and size
3. Creates opposite market order to close position
4. Shows position details and estimated P&L
5. Executes market order after confirmation

**Confirmation Dialog:**
```
🔴 Exit Position Confirmation

📊 Position Details:
• Token: BTC
• Position: LONG
• Size: 0.002211 contracts
• Entry Price: $45,230.50
• Current Price: $46,150.00
• 🟢 Unrealized P&L: $203.45

🎯 Exit Order:
• Action: SELL (Close LONG)
• Amount: 0.002211 BTC
• Est. Value: ~$102.03
• Order Type: Market Order

⚠️ Are you sure you want to close this LONG position?

This will place a market sell order to close your entire BTC position.
```

## 🛡️ Risk Management

### `/sl [token] [price]`
Set a stop loss order to limit downside risk.

**Usage:**
```
/sl <TOKEN> <PRICE>
```

**Examples:**
```
/sl BTC 44000   # Stop loss for Bitcoin at $44,000
/sl ETH 3200    # Stop loss for Ethereum at $3,200
```

**How it works:**
1. Checks for existing position in the specified token
2. Validates stop loss price against position direction:
   - **Long positions**: Stop loss must be BELOW entry price
   - **Short positions**: Stop loss must be ABOVE entry price
3. Places limit order at stop loss price
4. Order executes automatically when price is reached

**Confirmation Dialog:**
```
🛑 Stop Loss Order Confirmation

📊 Position Details:
• Token: BTC
• Position: LONG
• Size: 0.002211 contracts
• Entry Price: $45,230.50
• Current Price: $46,150.00

🎯 Stop Loss Order:
• Stop Price: $44,000.00
• Action: SELL (Close LONG)
• Amount: 0.002211 BTC
• Order Type: Limit Order
• 🔴 Est. P&L: -$272.15

⚠️ Are you sure you want to set this stop loss?

This will place a limit sell order at $44,000.00 to protect your LONG position.
```

### `/tp [token] [price]`
Set a take profit order to secure gains.

**Usage:**
```
/tp <TOKEN> <PRICE>
```

**Examples:**
```
/tp BTC 50000   # Take profit for Bitcoin at $50,000
/tp ETH 3800    # Take profit for Ethereum at $3,800
```

**How it works:**
1. Checks for existing position in the specified token
2. Validates take profit price against position direction:
   - **Long positions**: Take profit must be ABOVE entry price
   - **Short positions**: Take profit must be BELOW entry price
3. Places limit order at take profit price
4. Order executes automatically when price is reached

**Confirmation Dialog:**
```
🎯 Take Profit Order Confirmation

📊 Position Details:
• Token: BTC
• Position: LONG
• Size: 0.002211 contracts
• Entry Price: $45,230.50
• Current Price: $46,150.00

💰 Take Profit Order:
• Target Price: $50,000.00
• Action: SELL (Close LONG)
• Amount: 0.002211 BTC
• Order Type: Limit Order
• 🟢 Est. P&L: $1,054.35

⚠️ Are you sure you want to set this take profit?

This will place a limit sell order at $50,000.00 to capture profits from your LONG position.
```

## 📊 Market Data

### `/price [token (optional)]`
Quick price check for any token.

**Usage:**
```
/price           # Default trading token price
/price <TOKEN>   # Specific token price
```

**Examples:**
```
/price       # Default token price
/price BTC   # Bitcoin price
/price ETH   # Ethereum price
/price SOL   # Solana price
```

**Response:**
```
💵 BTC: $45,230.50
⏰ Updated: 14:25:30
💡 Usage: /price BTC or /price for default
```

### `/market [token (optional)]`
Detailed market data with orderbook information.

**Usage:**
```
/market           # Default trading token market data
/market <TOKEN>   # Specific token market data
```

**Examples:**
```
/market       # Default token market data
/market BTC   # Bitcoin market data
/market ETH   # Ethereum market data
```

**Response:**
```
📊 Market Data - BTC

💵 Current Price: $45,230.50
📈 24h High: $46,850.00
📉 24h Low: $44,120.00
📊 24h Volume: 2,450.25

🟢 Best Bid: $45,225.00
🔴 Best Ask: $45,235.00
📏 Spread: $10.00 (0.022%)

💡 Usage: /market BTC or /market for default
```

### `/trades`
Recent trade history.

**Example:**
```
/trades
```

**Response:**
```
🔄 Recent Trades

🟢 BUY 0.002211 BTC/USDC:USDC
   💰 $45,230.50 | 💵 $100.00
   📅 12/15 14:25

🔴 SELL 0.001850 ETH/USDC:USDC
   💰 $3,200.00 | 💵 $59.20
   📅 12/15 13:40

🟢 BUY 0.008500 SOL/USDC:USDC
   💰 $85.00 | 💵 $72.25
   📅 12/15 12:15
```

## 🔔 Price Alerts

### `/alarm [token] [price] OR [token] OR [alarm_id] OR (no args)`
Comprehensive price alert system with multiple usage patterns.

**Usage:**
```
/alarm                    # List all active alarms
/alarm <TOKEN>            # List alarms for specific token
/alarm <TOKEN> <PRICE>    # Set new alarm
/alarm <ALARM_ID>         # Remove alarm by ID
```

**Examples:**
```
/alarm                # List all alarms
/alarm BTC            # List Bitcoin alarms
/alarm BTC 50000      # Set BTC alarm at $50,000
/alarm ETH 3500       # Set ETH alarm at $3,500
/alarm 3              # Remove alarm ID 3
```

**Set New Alarm:**
```
/alarm BTC 50000
```

**Response:**
```
✅ Price Alarm Created

📊 Alarm Details:
• Alarm ID: 5
• Token: BTC
• Target Price: $50,000.00
• Current Price: $45,230.50
• Direction: ABOVE

📈 Alert Condition:
Will trigger when BTC price moves above $50,000.00

💰 Price Difference:
• Distance: $4,769.50 (10.55%)
• Status: ACTIVE ✅

⏰ Created: 14:25:30

💡 The alarm will be checked every 10 seconds and you'll receive a notification when triggered.
```

**List All Alarms:**
```
/alarm
```

**Response:**
```
🔔 Active Price Alarms (5 total)

🚨 Alarm #1: BTC
• Target: $50,000.00 (ABOVE)
• Current: $45,230.50
• Distance: $4,769.50 (10.55%)

🚨 Alarm #2: ETH  
• Target: $3,500.00 (ABOVE)
• Current: $3,200.00
• Distance: $300.00 (9.38%)

🚨 Alarm #3: BTC
• Target: $44,000.00 (BELOW)
• Current: $45,230.50
• Distance: $1,230.50 (2.72%)

💡 Usage:
• /alarm BTC - Show BTC alarms only
• /alarm BTC 52000 - Set new BTC alarm
• /alarm 3 - Remove alarm ID 3
```

**List Token Alarms:**
```
/alarm BTC
```

**Response:**
```
🔔 BTC Price Alarms (2 total)

🚨 Alarm #1: BTC
• Target: $50,000.00 (ABOVE)
• Current: $45,230.50
• Distance: $4,769.50 (10.55%)

🚨 Alarm #3: BTC
• Target: $44,000.00 (BELOW)
• Current: $45,230.50
• Distance: $1,230.50 (2.72%)

💡 Set new: /alarm BTC 52000
💡 Remove: /alarm 1 or /alarm 3
```

**Alarm Triggered Notification:**
```
🚨 PRICE ALARM TRIGGERED! 🚨

📊 Alarm Details:
• Token: BTC
• Target Price: $50,000.00
• Current Price: $50,125.50
• Direction: ABOVE

✅ Condition Met: BTC moved ABOVE $50,000.00
⏰ Triggered: 16:45:22
🎯 Alarm ID: 1 (automatically removed)

💡 Price has increased by $4,895.00 (+10.82%) since alarm was set.
```

**Remove Alarm:**
```
/alarm 3
```

**Response:**
```
✅ Alarm ID 3 has been removed.
```

## 🔄 Order Monitoring & Notifications

The bot automatically monitors your orders and positions every 10 seconds and sends real-time notifications when orders are filled.

### Automatic Notifications

**🚀 Position Opened Notifications**
```
🚀 Position Opened

📊 Trade Details:
• Token: BTC
• Direction: LONG
• Size: 0.002 contracts
• Entry Price: $45,230.50
• Value: $90.46

✅ Status: New LONG position opened
⏰ Time: 14:25:30

📱 Use /positions to view all positions
```

**🎯 Position Closed Notifications**
```
🎯 Position Closed

📊 Trade Summary:
• Token: BTC
• Direction: LONG
• Size: 0.002 contracts
• Entry Price: $45,230.50
• Exit Price: $46,150.00
• Exit Value: $92.30

🟢 Profit & Loss:
• P&L: $1.84 (+2.04%)
• Result: PROFIT

✅ Status: Position fully closed
⏰ Time: 16:45:22

📊 Use /stats to view updated performance
```

**📉 Partial Position Closed**
```
📉 Position Partially Closed

📊 Partial Close Details:
• Token: BTC
• Direction: LONG
• Closed Size: 0.001 contracts
• Entry Price: $45,230.50
• Exit Price: $46,150.00

🟢 Partial P&L:
• P&L: $0.92 (+2.04%)

✅ Status: Partial position closed
⏰ Time: 15:30:15

📈 Use /positions to view remaining position
```

**🔄 External Trade Detection**
```
🔄 External Trade Detected

📊 Trade Details:
• Token: ETH
• Side: BUY
• Amount: 0.015 ETH
• Price: $3,200.00
• Value: $48.00

🟢 Source: Direct Platform Trade
⏰ Time: 14:35:20

📈 Note: This trade was executed outside the Telegram bot
📊 Stats have been automatically updated
```

### `/monitoring`
Check the status of all monitoring systems.

**Example:**
```
/monitoring
```

**Response:**
```
🔄 System Monitoring Status

📊 Order Monitoring:
• Active: ✅ Yes
• Check Interval: 10 seconds
• Orders Tracked: 3
• Positions Tracked: 2

🔔 Price Alarms:
• Active Alarms: 5
• Triggered Today: 2
• Tokens Monitored: 3
• Next Alarm ID: 6

🔄 External Trade Monitoring:
• Last Check: 2024-12-15 14:25:30
• Auto Stats Update: ✅ Enabled
• External Notifications: ✅ Enabled

🛡️ Risk Management:
• Automatic Stop Loss: ❌ Disabled
• Stop Loss Threshold: 5.0%
• Position Monitoring: ❌ Inactive

📈 Notifications:
• 🚀 Position Opened/Increased
• 📉 Position Partially/Fully Closed
• 🎯 P&L Calculations
• 🔔 Price Alarm Triggers
• 🔄 External Trade Detection
• 🛑 Automatic Stop Loss Triggers

⏰ Last Check: 14:25:30

💡 Monitoring Features:
• Real-time order fill detection
• Automatic P&L calculation
• Position change tracking
• Price alarm monitoring
• External trade monitoring
• Auto stats synchronization
• Instant Telegram notifications

📋 Active Alarms by Token:
• BTC: 2 alarms
• ETH: 2 alarms
• SOL: 1 alarm
```

## 🗂️ System Management

### `/logs [cleanup] [days (optional)]`
View log file statistics and manage log cleanup.

**Usage:**
```
/logs                    # Show log statistics
/logs cleanup            # Clean logs older than 30 days (default)
/logs cleanup <DAYS>     # Clean logs older than specified days
```

**Examples:**
```
/logs               # View log stats
/logs cleanup       # Clean old logs (30 days)
/logs cleanup 7     # Clean logs older than 7 days
```

**Log Statistics:**
```
📊 System Logging Status

📁 Current Log Files:
• Main Log: trading_bot_20241215.log (2.5 MB)
• Error Log: bot_errors.log (0.8 MB)
• Archive Files: 5 files (12.3 MB total)

📈 Log Activity (Last 24h):
• Total Entries: 2,450
• Info: 2,180 (89%)
• Warning: 195 (8%)
• Error: 75 (3%)

💾 Disk Usage:
• Current Logs: 3.3 MB
• Archive Logs: 12.3 MB
• Total Usage: 15.6 MB

📈 Log Configuration:
• Log Level: INFO
• Heartbeat Interval: 30s
• Bot Uptime: 2024-12-15 14:25:30

💡 Log Management:
• /logs cleanup - Clean old logs (30 days)
• /logs cleanup 7 - Clean logs older than 7 days
• Log rotation happens automatically
• Old backups are removed automatically

🔧 Configuration:
• Rotation Type: SIZE
• Max Size: 10MB (size rotation)
• Backup Count: 5
```

**Log Cleanup:**
```
/logs cleanup 7
```

**Response:**
```
🧹 Cleaning up log files older than 7 days...
✅ Log cleanup completed!
```

### `/risk`
Show advanced risk metrics and portfolio analysis.

**Example:**
```
/risk
```

**Response:**
```
📊 Risk Analysis & Advanced Metrics

🎯 Risk-Adjusted Performance:
• Sharpe Ratio: 1.850
• Sortino Ratio: 2.410
• Annual Volatility: 12.30%

📉 Drawdown Analysis:
• Maximum Drawdown: 8.50%
• Value at Risk (95%): 3.20%

💰 Portfolio Context:
• Current Balance: $1,150.00
• Initial Balance: $1,000.00
• Total P&L: $150.00
• Days Active: 30

📊 Risk Interpretation:
• 🟢 Good risk-adjusted returns (Sharpe > 1.0)
• 🟢 Low maximum drawdown (< 15%)
• 🟡 Moderate portfolio volatility (< 25%)

💡 Risk Definitions:
• Sharpe Ratio: Risk-adjusted return (excess return / volatility)
• Sortino Ratio: Return / downside volatility (focuses on bad volatility)
• Max Drawdown: Largest peak-to-trough decline
• VaR 95%: Maximum expected loss 95% of the time
• Volatility: Annualized standard deviation of returns

📈 Data Based On:
• Completed Trades: 25
• Daily Balance Records: 30
• Trading Period: 30 days
```

### `/version`
Show bot version and system information.

**Example:**
```
/version
```

**Response:**
```
🤖 Trading Bot Version & System Info

📱 Bot Information:
• Version: v2.0.0
• Network: Mainnet
• Uptime: 2d 5h 30m
• Default Token: BTC

💻 System Information:
• Python: 3.11.5
• Platform: Darwin arm64
• Architecture: arm64

📊 Trading Stats:
• Total Orders: 45
• Completed Trades: 25
• Days Active: 30
• Start Date: 2024-01-15

🔄 Monitoring Status:
• Order Monitoring: ✅ Active
• External Trades: ✅ Active
• Price Alarms: ✅ Active (5 active)
• Risk Management: ❌ Disabled

⏰ Current Time: 2024-12-15 14:25:30
```

### `/balance_adjustments`
Show deposit and withdrawal history for accurate P&L tracking.

**Example:**
```
/balance_adjustments
```

**Response:**
```
💰 Balance Adjustments History

📊 Summary:
• Total Deposits: $500.00
• Total Withdrawals: $200.00
• Net Adjustment: $300.00
• Total Transactions: 3

📅 Recent Adjustments:
• 💰 12/15 09:30: +$200.00
• 💸 12/10 16:45: -$150.00
• 💰 12/05 11:20: +$300.00

💡 How it Works:
• Bot checks for deposits/withdrawals every hour
• Adjustments maintain accurate P&L calculations
• Non-trading balance changes don't affect performance metrics
• Trading statistics remain pure and accurate

⏰ Last Check: 12/15 14:00
```

## 💡 Pro Tips

### **🎯 Best Practices**
- Start small and test with small amounts first
- Use confirmations and always review orders
- Monitor positions regularly with `/positions`
- Track performance with `/stats` and `/performance`
- Set up price alerts with `/alarm` for key levels
- Review daily/weekly performance with `/daily` and `/weekly`

### **⚡ Quick Trading**
```bash
/long BTC 10         # Quick $10 long (market)
/long BTC 10 44000   # Quick $10 long at $44k (limit)
/sl BTC 42000        # Set stop loss
/tp BTC 48000        # Set take profit
/exit BTC            # Close position
```

### **🛡️ Risk Management**
```bash
# Long position protection
/long BTC 100        # Open long
/sl BTC 42000        # Stop loss 5% below
/tp BTC 50000        # Take profit 10% above
/alarm BTC 41000     # Emergency alert
```

### **📊 Performance Tracking**
```bash
/stats            # Overall performance
/performance      # Token rankings
/daily            # Daily breakdown
/weekly           # Weekly trends
/monthly          # Monthly analysis
/performance BTC  # Detailed BTC stats
```

### **🔔 Alert Management**
```bash
/alarm BTC 50000     # Set upside alert
/alarm BTC 40000     # Set downside alert
/alarm               # Check all alarms
/alarm BTC           # Check BTC alarms
/alarm 3             # Remove alarm ID 3
```

### **📊 Monitoring**
```bash
/balance          # Check account
/positions        # Monitor open trades
/monitoring       # Check system status
/orders           # All open orders
/logs             # System health
```

## ⚠️ Important Notes

### **🛡️ Safety Features**
- **Confirmation dialogs** for all trades
- **Auto-notifications** for order fills
- **Real-time monitoring** every 10 seconds
- **Comprehensive logging** of all activities
- **Price alerts** for key levels
- **External trade detection** and sync

### **🔄 Order Monitoring**
- **10-second intervals** for order fill detection
- **Automatic P&L calculation** for closed positions
- **Position change tracking** (opens, closes, increases)
- **Instant Telegram notifications** for all fills
- **External trade monitoring** and sync

### **📈 Performance Analytics**
- **Token-level performance tracking** with rankings
- **Period-based analysis** (daily/weekly/monthly)
- **Comprehensive statistics** with risk metrics
- **Real-time P&L calculations** with percentages
- **Trade history** and pattern analysis

### **🔔 Alert System**
- **Price alerts** with automatic monitoring
- **Customizable thresholds** for any token
- **Direction-based triggers** (above/below)
- **Automatic removal** after trigger
- **Multi-token support** with unlimited alerts

### **📱 Mobile Optimized**
- **One-tap buttons** for quick actions
- **Clean formatting** for mobile screens
- **Instant notifications** for trade results
- **Real-time order fill alerts**
- **Comprehensive emoji indicators**

## 🚀 Getting Started

1. **Configure**: Set up your `.env` file with API keys
2. **Test**: Start with `/balance` and `/price`
3. **Trade**: Try `/long BTC 10` for a small market order
4. **Monitor**: Use `/monitoring` to check auto-notifications
5. **Track**: Use `/positions`, `/stats`, and `/performance`
6. **Alerts**: Set up `/alarm BTC 50000` for price notifications
7. **Analyze**: Review `/daily`, `/weekly` performance

**Happy trading! 📱💰**